@@ -1,6 +1,6 @@
 #!/usr/bin/perl
 # -------------------------------------------------------
-# $Header: /home/cvs/dobackup/dobackup.pl,v 4.32 2004/03/16 17:52:04 imorgan Exp $
+# $Header: /home/cvs/dobackup/dobackup.pl,v 4.34 2005/05/31 18:08:01 imorgan Exp $
 # -------------------------------------------------------
 #
 # Copyright 1997-2004 Webcon, Inc.
@@ -116,7 +116,7 @@ our($LS);              $LS = "/bin/ls";
 our($ToBackupTempFile); $ToBackupTempFile="$BackupLogDir/BackupTemp.$$";
 
 # ------- Arguments from here to End Defaults
-our($opt_test, $opt_fullbackup, $opt_rotate, $opt_prepdisk);
+our($opt_test, $opt_fullbackup, $opt_rotate, $opt_prepdisk, $opt_setauto);
 # --------------- End Defaults
 
 # ------------- Begin Main Program -----------------------------------------
@@ -132,13 +132,46 @@ GetOptions ("test" => \$opt_test,
             "timestamp=i" => sub{ $TimeStampOverride = $_[1]; $Debug && print 'timestamp=',$TimeStampOverride,"\n"; },
             "config=s" => sub{ $ConfigFile = $_[1]; $Debug && print 'config=',$ConfigFile,"\n"; },
             "help|h|version|V" => \&ShowSyntax,
-            "debug|d:i" => sub{ $Debug=$_[1]; ($Debug == 0) && ($Debug = 1); } ) 
+            "debug|d:i" => sub{ $Debug=$_[1]; ($Debug == 0) && ($Debug = 1); },
+            "setauto=s" => \$opt_setauto )
     or &ShowSyntax;
 
 $Debug && print "Debug: ProcessOptions complete\n";
 &LoadConfig;
 $Debug && print "Debug: LoadConfig complete\n";
 
+#Special config-altering functions
+
+if ($opt_setauto) {
+  if ($SingleHostOverride) {
+    if ($opt_setauto eq 'on') {
+      $IniConfig->setval($SingleHostOverride,'Auto',1);
+      $IniConfig->RewriteConfig;
+      $Debug && print "Config file auto flag set on for host $SingleHostOverride.\n";
+    } elsif ($opt_setauto eq 'off') {
+      $IniConfig->setval($SingleHostOverride,'Auto',0);
+      $IniConfig->RewriteConfig;
+      $Debug && print "Config file auto flag set off for host $SingleHostOverride.\n";
+    } elsif ($opt_setauto eq 'toggle') {
+      our($temp);
+      $temp=$Auto{$SingleHostOverride};
+      $Debug && print "Auto flag for host $SingleHostOverride before=$temp.\n";
+      $temp=abs($temp-1);
+      $Debug && print "Auto flag for host $SingleHostOverride after=$temp.\n";
+      $IniConfig->setval($SingleHostOverride,'Auto',$temp);
+      $IniConfig->RewriteConfig;
+      print "Config file auto flag toggled ",($temp==1)?'on':'off'," for host $SingleHostOverride.\n";
+    } else {
+      print "Invalid argument \'$opt_setauto\' to --setauto.\n";
+      exit(1);
+    }
+  } else {
+    print "Option --setauto requires a --host. No host specified.\n";
+    exit(1);
+  }
+  exit(0);
+}
+
 #Per-Host backup functions
 
 # Remove hosts that shouldn't be auto-run
@@ -205,7 +238,7 @@ sub ShowSyntax {
   my($temp)=('');
 
   print "\nUsage: $ExecutableName <options>\n";
-  $temp = '$Revision: 4.32 $';
+  $temp = '$Revision: 4.34 $';
   ($temp) = ( $temp =~ /^\$Revision\:\ (.*?)\ \$$/ );
   print 'Version: ',"$temp\n";
   print <<EOF;
@@ -237,6 +270,10 @@ Supported options are:
                    upon completion of this backup. Used with --test will
                    rotate media immediately without doing a backup.
 
+  --setauto STRING When used in conjunction with --host, alter the automatic
+                   backup flag for the given host according to STRING, which
+                   can be one of 'on', 'off', or 'toggle', and then exit.
+
   Refer to the README for more verbose help.
 
 EOF
@@ -954,8 +991,8 @@ sub PerformBackup{
     $Return = 0xffff & system("$DF -h $Destination{$Host} |$Tail -1 |$TR -s ' ' |$Cut -f 4 -d ' ' > $BackupTimeStamp");
     if ($Return == 0) {
       chomp($Usage = `$Cat $BackupTimeStamp`);
-      $Debug && print "Command: $DF -B 1 $Destination{$Host} |$Tail -1 |$TR -s ' ' |$Cut -f 4 -d ' ' > $BackupTimeStamp\n";
-      $Return = 0xffff & system("$DF -B 1 $Destination{$Host} |$Tail -1 |$TR -s ' ' |$Cut -f 4 -d ' ' > $BackupTimeStamp");
+      $Debug && print "Command: $DF --block-size=1 $Destination{$Host} |$Tail -1 |$TR -s ' ' |$Cut -f 4 -d ' ' > $BackupTimeStamp\n";
+      $Return = 0xffff & system("$DF --block-size=1 $Destination{$Host} |$Tail -1 |$TR -s ' ' |$Cut -f 4 -d ' ' > $BackupTimeStamp");
       chomp($UsageExact = `$Cat $BackupTimeStamp`);
       unlink("$BackupTimeStamp");
       $Debug && print "Usage=$Usage ($UsageExact)\n";
@@ -1018,7 +1055,7 @@ sub Cleanup{
   open (MAILTHIS, "|$MailProg $BackupAdministrator");
   print MAILTHIS "To: $BackupAdministrator\nSubject: $Host ",($Debug?"Debug-mode":"Automated")," Backup Summary\n\n";
 
-  $temp = '$Revision: 4.32 $';
+  $temp = '$Revision: 4.34 $';
   ($temp) = ( $temp =~ /^\$Revision\:\ (.*?)\ \$$/ );
 
   print MAILTHIS "This is an automated backup report from $ExecutableName v$temp\n\n";
